@@ -15,7 +15,7 @@ if not hasattr(_dash, 'development'):
           'Make sure you don\'t have a file '
           'named \n"dash.py" in your current directory.', file=_sys.stderr)
     _sys.exit(1)
-"""
+
 _basepath = _os.path.dirname(__file__)
 _filepath = _os.path.abspath(_os.path.join(_basepath, 'package-info.json'))
 with open(_filepath) as f:
@@ -23,9 +23,6 @@ with open(_filepath) as f:
 
 package_name = package['name'].replace(' ', '_').replace('-', '_')
 __version__ = package['version']
-"""
-package_name = 'tweaked_graphviz'
-__version__ = '0.0.2'
 
 _current_path = _os.path.dirname(_os.path.abspath(__file__))
 
@@ -34,13 +31,13 @@ _this_module = _sys.modules[__name__]
 
 _js_dist = [
     {
-        'relative_package_path': 'dash_interactive_graphviz.min.js',
+        'relative_package_path': 'tweaked_graphviz.min.js',
         'external_url': 'https://unpkg.com/{0}@{2}/{1}/{1}.min.js'.format(
             package_name, __name__, __version__),
         'namespace': package_name
     },
     {
-        'relative_package_path': 'dash_interactive_graphviz.min.js.map',
+        'relative_package_path': 'tweaked_graphviz.min.js.map',
         'external_url': 'https://unpkg.com/{0}@{2}/{1}/{1}.min.js.map'.format(
             package_name, __name__, __version__),
         'namespace': package_name
